@@ -4,6 +4,7 @@ from yafowil.base import (
 )
 from yafowil.common import (
     generic_extractor,
+    generic_required_extractor,
     input_generic_renderer,
 )
 from yafowil.utils import (
@@ -40,7 +41,9 @@ def autocomplete_extractor(widget, data):
 
 factory.register(
     'autocomplete', 
-    extractors=[generic_extractor, autocomplete_extractor], 
+    extractors=[generic_extractor,
+                generic_required_extractor,
+                autocomplete_extractor], 
     edit_renderers=[input_generic_renderer, autocomplete_renderer])
 
 factory.doc['blueprint']['autocomplete'] = \
@@ -56,13 +59,20 @@ factory.defaults['autocomplete.class'] = 'autocomplete'
 
 factory.defaults['autocomplete.required_class'] = 'required'
 
-factory.defaults['autocomplete.delay'] = '300' #ms
-
-factory.defaults['autocomplete.minLength'] = '1' #characters
-
 factory.defaults['autocomplete.disabled'] = False 
 
 factory.defaults['autocomplete.size'] = None 
 
-factory.register_plan('autocompletefield',
-                      ['field', 'label', 'error', 'autocomplete'])
+factory.defaults['autocomplete.delay'] = '300'
+factory.doc['props']['autocomplete.delay'] = \
+"""Delay in milliseconds.
+"""
+
+factory.defaults['autocomplete.minLength'] = '1'
+factory.doc['props']['autocomplete.minLength'] = \
+"""Minimum input length to trigger autocomplete.
+"""
+
+factory.doc['props']['autocomplete.source'] = \
+"""Autocomplete source as python iterable or string defining JSON view callback.
+"""
